@@ -9,7 +9,7 @@ For detailed document, please see:
 
 # flake8: noqa
 
-__version__ = '7.12.1'
+__version__ = '7.13.0'
 
 from .auth import Auth, QiniuMacAuth
 
@@ -28,4 +28,4 @@ from .services.compute.app import AccountClient
 from .services.compute.qcos_api import QcosClient
 from .services.sms.sms import Sms
 from .services.pili.rtc_server_manager import RtcServer, get_room_token
-from .utils import urlsafe_base64_encode, urlsafe_base64_decode, etag, entry, canonical_mime_header_key
+from .utils import urlsafe_base64_encode, urlsafe_base64_decode, etag, entry, decode_entry, canonical_mime_header_key
